<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../maindialog.ui" line="14"/>
        <source>Special Effect Settings</source>
        <translation>Speciális ablakhatások</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="24"/>
        <source>Shadow</source>
        <translation>Árnyék</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="67"/>
        <source>The blur radius for shadows</source>
        <translation>Elmosási sugár</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="77"/>
        <source>The left offset for shadows</source>
        <translation>Bal határ</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="91"/>
        <source>The top offset for shadows</source>
        <translation>Felső határ</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="105"/>
        <source>The translucency for shadows</source>
        <translation>Áttetszőség</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="122"/>
        <source>Color of shadow</source>
        <translation>Árnyék színe</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="57"/>
        <source>Fix some weirdness with ARGB windows</source>
        <translation>ARGB ablakok javítása</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="60"/>
        <source>Zero the part of the shadow&apos;s mask behind the window</source>
        <translation>Ablak mögötti árnyékmaszk lekapcsolása</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="50"/>
        <source>Don&apos;t draw shadows on DND windows</source>
        <translation>Ablakmozgatásnál nincs árnyék</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="43"/>
        <source>Avoid drawing shadows on dock/panel windows</source>
        <translation>Dokk/Panel árnyéktalan</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="36"/>
        <source>Enable client-side shadows on windows</source>
        <translation>Ablakok kliensoldali árnyékolása</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="136"/>
        <source>Avoid drawing shadow on all shaped windows</source>
        <translation>Formázott ablakok árnyéktalanok</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="143"/>
        <source>Crop shadows of maximized windows from extended displays</source>
        <translation>A maximalizált ablakok árnyékának kivágása a kibővített kijelzőkről</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="151"/>
        <source>Opacity</source>
        <translation>Áttetszőség</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="160"/>
        <source>The opacity for menus</source>
        <translation>Menüáttetszőség</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="167"/>
        <source>Default opacity of inactive windows</source>
        <translation>Inaktív ablak alap áttetszősége</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="174"/>
        <source>Default opacity for active windows</source>
        <translation>Aktív ablak alapértelmezett áttetszősége</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="181"/>
        <source>Opacity of window titlebars and borders</source>
        <translation>Ablakfejléc és keret alap áttetszősége</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="188"/>
        <source>XRender backend: Step size for alpha pictures
(Increasing it may result in less X resource usage)</source>
        <translation>XRender Backend: Áttetsző képek fokozatai
(Nagyobb értékek kisebb grafikai terheltséget adnak)</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="196"/>
        <source>Dim inactive windows</source>
        <translation>Inaktív ablakok elsötétítése</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="203"/>
        <source>Do not let dimness adjust based on window opacity</source>
        <translation>Elsötétítés az ablak áttetszőségétől függetlenül</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="210"/>
        <source>Blur background of transparent windows</source>
        <translation>Áttetsző ablakok hátterének elmosása</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="217"/>
        <source>Blur background of opaque windows with transparent frames as well</source>
        <translation>Áttetsző keretű átlátszatlan ablakok háttere is elmosott</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="224"/>
        <source>Do not let blur radius adjust based on window opacity</source>
        <translation>Ablak áttetszőségétől az elmosási sugár független</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="292"/>
        <source>Fade</source>
        <translation>Áttűnés</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="298"/>
        <source>Fade windows during opacity changes</source>
        <translation>Áttetszőségi változásnál áttűnési hatás</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="305"/>
        <source>The time between steps in a fade in milliseconds</source>
        <translation>Áttűnési sebesség ms</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="312"/>
        <source>Opacity change between steps while fading in</source>
        <translation>Előtűnésnél áttetszőségi változás</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="319"/>
        <source>Opacity change between steps while fading out</source>
        <translation>Eltűnésnél áttetszőségi változás</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="326"/>
        <source>Avoid fade windows in/out when opening/closing</source>
        <translation>Ablaknyitásnál, zárásnál nincs áttűnés</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="369"/>
        <source>Other</source>
        <translation>Egyéb</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="381"/>
        <source>Rendering backend</source>
        <translation>Képkészítő API</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="393"/>
        <source>X Render</source>
        <translation>X Render</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="400"/>
        <source>GLX (OpenGL)</source>
        <translation>GLX (OpenGL)</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="416"/>
        <source>About</source>
        <translation>Névjegy</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="209"/>
        <source>About ComptonConf</source>
        <translation>A ComptonConf névjegye</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="210"/>
        <source>ComptonConf - configuration tool for compton

Copyright (C) 2013
Author: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>ComptonConf - Compton beállító eszköz

Copyright (C) 2013
Szerző: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
</context>
</TS>
